"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .addpermissionsop import (
    AddPermissionsPermissions,
    AddPermissionsPermissionsTypedDict,
    AddPermissionsRequestBody,
    AddPermissionsRequestBodyTypedDict,
    AddPermissionsResponse,
    AddPermissionsResponseTypedDict,
    ResponseBody,
    ResponseBodyTypedDict,
)
from .addrolesop import (
    AddRolesRequestBody,
    AddRolesRequestBodyTypedDict,
    AddRolesResponse,
    AddRolesResponseBody,
    AddRolesResponseBodyTypedDict,
    AddRolesResponseTypedDict,
    AddRolesRoles,
    AddRolesRolesTypedDict,
)
from .createapiop import (
    CreateAPIRequestBody,
    CreateAPIRequestBodyTypedDict,
    CreateAPIResponse,
    CreateAPIResponseBody,
    CreateAPIResponseBodyTypedDict,
    CreateAPIResponseTypedDict,
)
from .createidentityop import (
    CreateIdentityRatelimits,
    CreateIdentityRatelimitsTypedDict,
    CreateIdentityRequestBody,
    CreateIdentityRequestBodyTypedDict,
    CreateIdentityResponse,
    CreateIdentityResponseBody,
    CreateIdentityResponseBodyTypedDict,
    CreateIdentityResponseTypedDict,
)
from .createkeyop import (
    CreateKeyInterval,
    CreateKeyRatelimit,
    CreateKeyRatelimitTypedDict,
    CreateKeyRefill,
    CreateKeyRefillTypedDict,
    CreateKeyRequestBody,
    CreateKeyRequestBodyTypedDict,
    CreateKeyResponse,
    CreateKeyResponseBody,
    CreateKeyResponseBodyTypedDict,
    CreateKeyResponseTypedDict,
    CreateKeyType,
)
from .createpermissionop import (
    CreatePermissionRequestBody,
    CreatePermissionRequestBodyTypedDict,
    CreatePermissionResponse,
    CreatePermissionResponseBody,
    CreatePermissionResponseBodyTypedDict,
    CreatePermissionResponseTypedDict,
    Description,
    DescriptionTypedDict,
    Two,
)
from .createroleop import (
    CreateRoleDescription,
    CreateRoleDescriptionTypedDict,
    CreateRoleRequestBody,
    CreateRoleRequestBodyTypedDict,
    CreateRoleResponse,
    CreateRoleResponseBody,
    CreateRoleResponseBodyTypedDict,
    CreateRoleResponseTypedDict,
    Description2,
)
from .deleteapiop import (
    DeleteAPIRequestBody,
    DeleteAPIRequestBodyTypedDict,
    DeleteAPIResponse,
    DeleteAPIResponseBody,
    DeleteAPIResponseBodyTypedDict,
    DeleteAPIResponseTypedDict,
)
from .deleteidentityop import (
    DeleteIdentityRequestBody,
    DeleteIdentityRequestBodyTypedDict,
    DeleteIdentityResponse,
    DeleteIdentityResponseBody,
    DeleteIdentityResponseBodyTypedDict,
    DeleteIdentityResponseTypedDict,
)
from .deletekeyop import (
    DeleteKeyRequestBody,
    DeleteKeyRequestBodyTypedDict,
    DeleteKeyResponse,
    DeleteKeyResponseBody,
    DeleteKeyResponseBodyTypedDict,
    DeleteKeyResponseTypedDict,
)
from .deletekeysop import (
    DeleteKeysRequestBody,
    DeleteKeysRequestBodyTypedDict,
    DeleteKeysResponse,
    DeleteKeysResponseBody,
    DeleteKeysResponseBodyTypedDict,
    DeleteKeysResponseTypedDict,
)
from .deleteoverrideop import (
    DeleteOverrideRequestBody,
    DeleteOverrideRequestBodyTypedDict,
    DeleteOverrideResponse,
    DeleteOverrideResponseBody,
    DeleteOverrideResponseBodyTypedDict,
    DeleteOverrideResponseTypedDict,
)
from .deletepermissionop import (
    DeletePermissionRequestBody,
    DeletePermissionRequestBodyTypedDict,
    DeletePermissionResponse,
    DeletePermissionResponseBody,
    DeletePermissionResponseBodyTypedDict,
    DeletePermissionResponseTypedDict,
)
from .deleteroleop import (
    DeleteRoleRequestBody,
    DeleteRoleRequestBodyTypedDict,
    DeleteRoleResponse,
    DeleteRoleResponseBody,
    DeleteRoleResponseBodyTypedDict,
    DeleteRoleResponseTypedDict,
)
from .errbadrequest import (
    ErrBadRequest,
    ErrBadRequestCode,
    ErrBadRequestData,
    Error,
    ErrorTypedDict,
)
from .errconflict import (
    ErrConflict,
    ErrConflictCode,
    ErrConflictData,
    ErrConflictError,
    ErrConflictErrorTypedDict,
)
from .errdeleteprotected import (
    ErrDeleteProtected,
    ErrDeleteProtectedCode,
    ErrDeleteProtectedData,
    ErrDeleteProtectedError,
    ErrDeleteProtectedErrorTypedDict,
)
from .errforbidden import (
    ErrForbidden,
    ErrForbiddenCode,
    ErrForbiddenData,
    ErrForbiddenError,
    ErrForbiddenErrorTypedDict,
)
from .errinternalservererror import (
    ErrInternalServerError,
    ErrInternalServerErrorCode,
    ErrInternalServerErrorData,
    ErrInternalServerErrorError,
    ErrInternalServerErrorErrorTypedDict,
)
from .errnotfound import (
    ErrNotFound,
    ErrNotFoundCode,
    ErrNotFoundData,
    ErrNotFoundError,
    ErrNotFoundErrorTypedDict,
)
from .errpreconditionfailed import (
    ErrPreconditionFailed,
    ErrPreconditionFailedCode,
    ErrPreconditionFailedData,
    ErrPreconditionFailedError,
    ErrPreconditionFailedErrorTypedDict,
)
from .errtoomanyrequests import (
    ErrTooManyRequests,
    ErrTooManyRequestsCode,
    ErrTooManyRequestsData,
    ErrTooManyRequestsError,
    ErrTooManyRequestsErrorTypedDict,
)
from .errunauthorized import (
    ErrUnauthorized,
    ErrUnauthorizedCode,
    ErrUnauthorizedData,
    ErrUnauthorizedError,
    ErrUnauthorizedErrorTypedDict,
)
from .getapiop import (
    GetAPIRequest,
    GetAPIRequestTypedDict,
    GetAPIResponse,
    GetAPIResponseBody,
    GetAPIResponseBodyTypedDict,
    GetAPIResponseTypedDict,
)
from .getidentityop import (
    GetIdentityRatelimits,
    GetIdentityRatelimitsTypedDict,
    GetIdentityRequest,
    GetIdentityRequestTypedDict,
    GetIdentityResponse,
    GetIdentityResponseBody,
    GetIdentityResponseBodyTypedDict,
    GetIdentityResponseTypedDict,
)
from .getkeyop import (
    GetKeyRequest,
    GetKeyRequestTypedDict,
    GetKeyResponse,
    GetKeyResponseTypedDict,
)
from .getoverrideop import (
    GetOverrideRequest,
    GetOverrideRequestTypedDict,
    GetOverrideResponse,
    GetOverrideResponseBody,
    GetOverrideResponseBodyTypedDict,
    GetOverrideResponseTypedDict,
)
from .getpermissionop import (
    GetPermissionRequest,
    GetPermissionRequestTypedDict,
    GetPermissionResponse,
    GetPermissionResponseBody,
    GetPermissionResponseBodyTypedDict,
    GetPermissionResponseTypedDict,
)
from .getroleop import (
    GetRoleRequest,
    GetRoleRequestTypedDict,
    GetRoleResponse,
    GetRoleResponseBody,
    GetRoleResponseBodyTypedDict,
    GetRoleResponseTypedDict,
)
from .getverificationsop import (
    GetVerificationsIdentity,
    GetVerificationsIdentityTypedDict,
    GetVerificationsRequest,
    GetVerificationsRequestTypedDict,
    GetVerificationsResponse,
    GetVerificationsResponseBody,
    GetVerificationsResponseBodyTypedDict,
    GetVerificationsResponseTypedDict,
    GroupBy,
    GroupByTypedDict,
    KeyID,
    KeyIDTypedDict,
    One,
    Order,
    OrderBy,
    QueryParam2,
    Tag,
    TagTypedDict,
)
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
from .key import (
    Identity,
    IdentityTypedDict,
    Interval,
    Key,
    KeyTypedDict,
    RatelimitModel,
    RatelimitModelTypedDict,
    Refill,
    RefillTypedDict,
    Type,
)
from .keys_getverificationsop import (
    Granularity,
    KeysGetVerificationsRequest,
    KeysGetVerificationsRequestTypedDict,
    KeysGetVerificationsResponse,
    KeysGetVerificationsResponseBody,
    KeysGetVerificationsResponseBodyTypedDict,
    KeysGetVerificationsResponseTypedDict,
    Verifications,
    VerificationsTypedDict,
)
from .limitop import (
    LimitRequestBody,
    LimitRequestBodyTypedDict,
    LimitResponse,
    LimitResponseBody,
    LimitResponseBodyTypedDict,
    LimitResponseTypedDict,
    Resources,
    ResourcesTypedDict,
)
from .listidentitiesop import (
    ListIdentitiesIdentities,
    ListIdentitiesIdentitiesTypedDict,
    ListIdentitiesRatelimits,
    ListIdentitiesRatelimitsTypedDict,
    ListIdentitiesRequest,
    ListIdentitiesRequestTypedDict,
    ListIdentitiesResponse,
    ListIdentitiesResponseBody,
    ListIdentitiesResponseBodyTypedDict,
    ListIdentitiesResponseTypedDict,
)
from .listkeysop import (
    ListKeysRequest,
    ListKeysRequestTypedDict,
    ListKeysResponse,
    ListKeysResponseBody,
    ListKeysResponseBodyTypedDict,
    ListKeysResponseTypedDict,
)
from .listoverridesop import (
    ListOverridesRequest,
    ListOverridesRequestTypedDict,
    ListOverridesResponse,
    ListOverridesResponseBody,
    ListOverridesResponseBodyTypedDict,
    ListOverridesResponseTypedDict,
    Overrides,
    OverridesTypedDict,
)
from .listpermissionsop import (
    ListPermissionsResponse,
    ListPermissionsResponseBody,
    ListPermissionsResponseBodyTypedDict,
    ListPermissionsResponseTypedDict,
)
from .listrolesop import (
    ListRolesResponse,
    ListRolesResponseBody,
    ListRolesResponseBodyTypedDict,
    ListRolesResponseTypedDict,
)
from .permissionquery import (
    And,
    AndTypedDict,
    Or,
    OrTypedDict,
    PermissionQuery,
    PermissionQueryTypedDict,
)
from .removepermissionsop import (
    RemovePermissionsPermissions,
    RemovePermissionsPermissionsTypedDict,
    RemovePermissionsRequestBody,
    RemovePermissionsRequestBodyTypedDict,
    RemovePermissionsResponse,
    RemovePermissionsResponseBody,
    RemovePermissionsResponseBodyTypedDict,
    RemovePermissionsResponseTypedDict,
)
from .removerolesop import (
    RemoveRolesRequestBody,
    RemoveRolesRequestBodyTypedDict,
    RemoveRolesResponse,
    RemoveRolesResponseBody,
    RemoveRolesResponseBodyTypedDict,
    RemoveRolesResponseTypedDict,
    RemoveRolesRoles,
    RemoveRolesRolesTypedDict,
)
from .sdkerror import SDKError
from .security import Security, SecurityTypedDict
from .setoverrideop import (
    SetOverrideRequestBody,
    SetOverrideRequestBodyTypedDict,
    SetOverrideResponse,
    SetOverrideResponseBody,
    SetOverrideResponseBodyTypedDict,
    SetOverrideResponseTypedDict,
)
from .setpermissionsop import (
    SetPermissionsPermissions,
    SetPermissionsPermissionsTypedDict,
    SetPermissionsRequestBody,
    SetPermissionsRequestBodyTypedDict,
    SetPermissionsResponse,
    SetPermissionsResponseBody,
    SetPermissionsResponseBodyTypedDict,
    SetPermissionsResponseTypedDict,
)
from .setrolesop import (
    SetRolesRequestBody,
    SetRolesRequestBodyTypedDict,
    SetRolesResponse,
    SetRolesResponseBody,
    SetRolesResponseBodyTypedDict,
    SetRolesResponseTypedDict,
    SetRolesRoles,
    SetRolesRolesTypedDict,
)
from .updateidentityop import (
    UpdateIdentityIdentitiesRatelimits,
    UpdateIdentityIdentitiesRatelimitsTypedDict,
    UpdateIdentityRatelimits,
    UpdateIdentityRatelimitsTypedDict,
    UpdateIdentityRequestBody,
    UpdateIdentityRequestBodyTypedDict,
    UpdateIdentityResponse,
    UpdateIdentityResponseBody,
    UpdateIdentityResponseBodyTypedDict,
    UpdateIdentityResponseTypedDict,
)
from .updatekeyop import (
    Roles,
    RolesTypedDict,
    UpdateKeyInterval,
    UpdateKeyPermissions,
    UpdateKeyPermissionsTypedDict,
    UpdateKeyRatelimit,
    UpdateKeyRatelimitTypedDict,
    UpdateKeyRefill,
    UpdateKeyRefillTypedDict,
    UpdateKeyRequestBody,
    UpdateKeyRequestBodyTypedDict,
    UpdateKeyResponse,
    UpdateKeyResponseBody,
    UpdateKeyResponseBodyTypedDict,
    UpdateKeyResponseTypedDict,
    UpdateKeyType,
)
from .updateremainingop import (
    Op,
    UpdateRemainingRequestBody,
    UpdateRemainingRequestBodyTypedDict,
    UpdateRemainingResponse,
    UpdateRemainingResponseBody,
    UpdateRemainingResponseBodyTypedDict,
    UpdateRemainingResponseTypedDict,
)
from .v1_livenessop import (
    Services,
    ServicesTypedDict,
    V1LivenessResponse,
    V1LivenessResponseBody,
    V1LivenessResponseBodyTypedDict,
    V1LivenessResponseTypedDict,
)
from .v1_migrations_createkeysop import (
    Hash,
    HashTypedDict,
    RequestBody,
    RequestBodyTypedDict,
    V1MigrationsCreateKeysInterval,
    V1MigrationsCreateKeysRatelimit,
    V1MigrationsCreateKeysRatelimitTypedDict,
    V1MigrationsCreateKeysRefill,
    V1MigrationsCreateKeysRefillTypedDict,
    V1MigrationsCreateKeysResponse,
    V1MigrationsCreateKeysResponseBody,
    V1MigrationsCreateKeysResponseBodyTypedDict,
    V1MigrationsCreateKeysResponseTypedDict,
    V1MigrationsCreateKeysType,
    Variant,
)
from .v1_migrations_enqueuekeysop import (
    V1MigrationsEnqueueKeysHash,
    V1MigrationsEnqueueKeysHashTypedDict,
    V1MigrationsEnqueueKeysInterval,
    V1MigrationsEnqueueKeysKeys,
    V1MigrationsEnqueueKeysKeysTypedDict,
    V1MigrationsEnqueueKeysRatelimit,
    V1MigrationsEnqueueKeysRatelimitTypedDict,
    V1MigrationsEnqueueKeysRefill,
    V1MigrationsEnqueueKeysRefillTypedDict,
    V1MigrationsEnqueueKeysRequestBody,
    V1MigrationsEnqueueKeysRequestBodyTypedDict,
    V1MigrationsEnqueueKeysResponse,
    V1MigrationsEnqueueKeysResponseBody,
    V1MigrationsEnqueueKeysResponseBodyTypedDict,
    V1MigrationsEnqueueKeysResponseTypedDict,
    V1MigrationsEnqueueKeysType,
    V1MigrationsEnqueueKeysVariant,
)
from .v1keysverifykeyrequest import (
    Authorization,
    AuthorizationTypedDict,
    RatelimitsModel,
    RatelimitsModelTypedDict,
    Remaining,
    RemainingTypedDict,
    V1KeysVerifyKeyRequest,
    V1KeysVerifyKeyRequestRatelimit,
    V1KeysVerifyKeyRequestRatelimitTypedDict,
    V1KeysVerifyKeyRequestTypedDict,
)
from .v1keysverifykeyresponse import (
    Code,
    V1KeysVerifyKeyResponse,
    V1KeysVerifyKeyResponseIdentity,
    V1KeysVerifyKeyResponseIdentityTypedDict,
    V1KeysVerifyKeyResponseRatelimit,
    V1KeysVerifyKeyResponseRatelimitTypedDict,
    V1KeysVerifyKeyResponseTypedDict,
)
from .verifykeyop import VerifyKeyResponse, VerifyKeyResponseTypedDict
from .whoamiop import (
    WhoamiIdentity,
    WhoamiIdentityTypedDict,
    WhoamiRequestBody,
    WhoamiRequestBodyTypedDict,
    WhoamiResponse,
    WhoamiResponseBody,
    WhoamiResponseBodyTypedDict,
    WhoamiResponseTypedDict,
)

# Pydantic models with forward references
Or.model_rebuild()
And.model_rebuild()

__all__ = [
    "AddPermissionsPermissions",
    "AddPermissionsPermissionsTypedDict",
    "AddPermissionsRequestBody",
    "AddPermissionsRequestBodyTypedDict",
    "AddPermissionsResponse",
    "AddPermissionsResponseTypedDict",
    "AddRolesRequestBody",
    "AddRolesRequestBodyTypedDict",
    "AddRolesResponse",
    "AddRolesResponseBody",
    "AddRolesResponseBodyTypedDict",
    "AddRolesResponseTypedDict",
    "AddRolesRoles",
    "AddRolesRolesTypedDict",
    "And",
    "AndTypedDict",
    "Authorization",
    "AuthorizationTypedDict",
    "Code",
    "CreateAPIRequestBody",
    "CreateAPIRequestBodyTypedDict",
    "CreateAPIResponse",
    "CreateAPIResponseBody",
    "CreateAPIResponseBodyTypedDict",
    "CreateAPIResponseTypedDict",
    "CreateIdentityRatelimits",
    "CreateIdentityRatelimitsTypedDict",
    "CreateIdentityRequestBody",
    "CreateIdentityRequestBodyTypedDict",
    "CreateIdentityResponse",
    "CreateIdentityResponseBody",
    "CreateIdentityResponseBodyTypedDict",
    "CreateIdentityResponseTypedDict",
    "CreateKeyInterval",
    "CreateKeyRatelimit",
    "CreateKeyRatelimitTypedDict",
    "CreateKeyRefill",
    "CreateKeyRefillTypedDict",
    "CreateKeyRequestBody",
    "CreateKeyRequestBodyTypedDict",
    "CreateKeyResponse",
    "CreateKeyResponseBody",
    "CreateKeyResponseBodyTypedDict",
    "CreateKeyResponseTypedDict",
    "CreateKeyType",
    "CreatePermissionRequestBody",
    "CreatePermissionRequestBodyTypedDict",
    "CreatePermissionResponse",
    "CreatePermissionResponseBody",
    "CreatePermissionResponseBodyTypedDict",
    "CreatePermissionResponseTypedDict",
    "CreateRoleDescription",
    "CreateRoleDescriptionTypedDict",
    "CreateRoleRequestBody",
    "CreateRoleRequestBodyTypedDict",
    "CreateRoleResponse",
    "CreateRoleResponseBody",
    "CreateRoleResponseBodyTypedDict",
    "CreateRoleResponseTypedDict",
    "DeleteAPIRequestBody",
    "DeleteAPIRequestBodyTypedDict",
    "DeleteAPIResponse",
    "DeleteAPIResponseBody",
    "DeleteAPIResponseBodyTypedDict",
    "DeleteAPIResponseTypedDict",
    "DeleteIdentityRequestBody",
    "DeleteIdentityRequestBodyTypedDict",
    "DeleteIdentityResponse",
    "DeleteIdentityResponseBody",
    "DeleteIdentityResponseBodyTypedDict",
    "DeleteIdentityResponseTypedDict",
    "DeleteKeyRequestBody",
    "DeleteKeyRequestBodyTypedDict",
    "DeleteKeyResponse",
    "DeleteKeyResponseBody",
    "DeleteKeyResponseBodyTypedDict",
    "DeleteKeyResponseTypedDict",
    "DeleteKeysRequestBody",
    "DeleteKeysRequestBodyTypedDict",
    "DeleteKeysResponse",
    "DeleteKeysResponseBody",
    "DeleteKeysResponseBodyTypedDict",
    "DeleteKeysResponseTypedDict",
    "DeleteOverrideRequestBody",
    "DeleteOverrideRequestBodyTypedDict",
    "DeleteOverrideResponse",
    "DeleteOverrideResponseBody",
    "DeleteOverrideResponseBodyTypedDict",
    "DeleteOverrideResponseTypedDict",
    "DeletePermissionRequestBody",
    "DeletePermissionRequestBodyTypedDict",
    "DeletePermissionResponse",
    "DeletePermissionResponseBody",
    "DeletePermissionResponseBodyTypedDict",
    "DeletePermissionResponseTypedDict",
    "DeleteRoleRequestBody",
    "DeleteRoleRequestBodyTypedDict",
    "DeleteRoleResponse",
    "DeleteRoleResponseBody",
    "DeleteRoleResponseBodyTypedDict",
    "DeleteRoleResponseTypedDict",
    "Description",
    "Description2",
    "DescriptionTypedDict",
    "ErrBadRequest",
    "ErrBadRequestCode",
    "ErrBadRequestData",
    "ErrConflict",
    "ErrConflictCode",
    "ErrConflictData",
    "ErrConflictError",
    "ErrConflictErrorTypedDict",
    "ErrDeleteProtected",
    "ErrDeleteProtectedCode",
    "ErrDeleteProtectedData",
    "ErrDeleteProtectedError",
    "ErrDeleteProtectedErrorTypedDict",
    "ErrForbidden",
    "ErrForbiddenCode",
    "ErrForbiddenData",
    "ErrForbiddenError",
    "ErrForbiddenErrorTypedDict",
    "ErrInternalServerError",
    "ErrInternalServerErrorCode",
    "ErrInternalServerErrorData",
    "ErrInternalServerErrorError",
    "ErrInternalServerErrorErrorTypedDict",
    "ErrNotFound",
    "ErrNotFoundCode",
    "ErrNotFoundData",
    "ErrNotFoundError",
    "ErrNotFoundErrorTypedDict",
    "ErrPreconditionFailed",
    "ErrPreconditionFailedCode",
    "ErrPreconditionFailedData",
    "ErrPreconditionFailedError",
    "ErrPreconditionFailedErrorTypedDict",
    "ErrTooManyRequests",
    "ErrTooManyRequestsCode",
    "ErrTooManyRequestsData",
    "ErrTooManyRequestsError",
    "ErrTooManyRequestsErrorTypedDict",
    "ErrUnauthorized",
    "ErrUnauthorizedCode",
    "ErrUnauthorizedData",
    "ErrUnauthorizedError",
    "ErrUnauthorizedErrorTypedDict",
    "Error",
    "ErrorTypedDict",
    "GetAPIRequest",
    "GetAPIRequestTypedDict",
    "GetAPIResponse",
    "GetAPIResponseBody",
    "GetAPIResponseBodyTypedDict",
    "GetAPIResponseTypedDict",
    "GetIdentityRatelimits",
    "GetIdentityRatelimitsTypedDict",
    "GetIdentityRequest",
    "GetIdentityRequestTypedDict",
    "GetIdentityResponse",
    "GetIdentityResponseBody",
    "GetIdentityResponseBodyTypedDict",
    "GetIdentityResponseTypedDict",
    "GetKeyRequest",
    "GetKeyRequestTypedDict",
    "GetKeyResponse",
    "GetKeyResponseTypedDict",
    "GetOverrideRequest",
    "GetOverrideRequestTypedDict",
    "GetOverrideResponse",
    "GetOverrideResponseBody",
    "GetOverrideResponseBodyTypedDict",
    "GetOverrideResponseTypedDict",
    "GetPermissionRequest",
    "GetPermissionRequestTypedDict",
    "GetPermissionResponse",
    "GetPermissionResponseBody",
    "GetPermissionResponseBodyTypedDict",
    "GetPermissionResponseTypedDict",
    "GetRoleRequest",
    "GetRoleRequestTypedDict",
    "GetRoleResponse",
    "GetRoleResponseBody",
    "GetRoleResponseBodyTypedDict",
    "GetRoleResponseTypedDict",
    "GetVerificationsIdentity",
    "GetVerificationsIdentityTypedDict",
    "GetVerificationsRequest",
    "GetVerificationsRequestTypedDict",
    "GetVerificationsResponse",
    "GetVerificationsResponseBody",
    "GetVerificationsResponseBodyTypedDict",
    "GetVerificationsResponseTypedDict",
    "Granularity",
    "GroupBy",
    "GroupByTypedDict",
    "HTTPMetadata",
    "HTTPMetadataTypedDict",
    "Hash",
    "HashTypedDict",
    "Identity",
    "IdentityTypedDict",
    "Interval",
    "Key",
    "KeyID",
    "KeyIDTypedDict",
    "KeyTypedDict",
    "KeysGetVerificationsRequest",
    "KeysGetVerificationsRequestTypedDict",
    "KeysGetVerificationsResponse",
    "KeysGetVerificationsResponseBody",
    "KeysGetVerificationsResponseBodyTypedDict",
    "KeysGetVerificationsResponseTypedDict",
    "LimitRequestBody",
    "LimitRequestBodyTypedDict",
    "LimitResponse",
    "LimitResponseBody",
    "LimitResponseBodyTypedDict",
    "LimitResponseTypedDict",
    "ListIdentitiesIdentities",
    "ListIdentitiesIdentitiesTypedDict",
    "ListIdentitiesRatelimits",
    "ListIdentitiesRatelimitsTypedDict",
    "ListIdentitiesRequest",
    "ListIdentitiesRequestTypedDict",
    "ListIdentitiesResponse",
    "ListIdentitiesResponseBody",
    "ListIdentitiesResponseBodyTypedDict",
    "ListIdentitiesResponseTypedDict",
    "ListKeysRequest",
    "ListKeysRequestTypedDict",
    "ListKeysResponse",
    "ListKeysResponseBody",
    "ListKeysResponseBodyTypedDict",
    "ListKeysResponseTypedDict",
    "ListOverridesRequest",
    "ListOverridesRequestTypedDict",
    "ListOverridesResponse",
    "ListOverridesResponseBody",
    "ListOverridesResponseBodyTypedDict",
    "ListOverridesResponseTypedDict",
    "ListPermissionsResponse",
    "ListPermissionsResponseBody",
    "ListPermissionsResponseBodyTypedDict",
    "ListPermissionsResponseTypedDict",
    "ListRolesResponse",
    "ListRolesResponseBody",
    "ListRolesResponseBodyTypedDict",
    "ListRolesResponseTypedDict",
    "One",
    "Op",
    "Or",
    "OrTypedDict",
    "Order",
    "OrderBy",
    "Overrides",
    "OverridesTypedDict",
    "PermissionQuery",
    "PermissionQueryTypedDict",
    "QueryParam2",
    "RatelimitModel",
    "RatelimitModelTypedDict",
    "RatelimitsModel",
    "RatelimitsModelTypedDict",
    "Refill",
    "RefillTypedDict",
    "Remaining",
    "RemainingTypedDict",
    "RemovePermissionsPermissions",
    "RemovePermissionsPermissionsTypedDict",
    "RemovePermissionsRequestBody",
    "RemovePermissionsRequestBodyTypedDict",
    "RemovePermissionsResponse",
    "RemovePermissionsResponseBody",
    "RemovePermissionsResponseBodyTypedDict",
    "RemovePermissionsResponseTypedDict",
    "RemoveRolesRequestBody",
    "RemoveRolesRequestBodyTypedDict",
    "RemoveRolesResponse",
    "RemoveRolesResponseBody",
    "RemoveRolesResponseBodyTypedDict",
    "RemoveRolesResponseTypedDict",
    "RemoveRolesRoles",
    "RemoveRolesRolesTypedDict",
    "RequestBody",
    "RequestBodyTypedDict",
    "Resources",
    "ResourcesTypedDict",
    "ResponseBody",
    "ResponseBodyTypedDict",
    "Roles",
    "RolesTypedDict",
    "SDKError",
    "Security",
    "SecurityTypedDict",
    "Services",
    "ServicesTypedDict",
    "SetOverrideRequestBody",
    "SetOverrideRequestBodyTypedDict",
    "SetOverrideResponse",
    "SetOverrideResponseBody",
    "SetOverrideResponseBodyTypedDict",
    "SetOverrideResponseTypedDict",
    "SetPermissionsPermissions",
    "SetPermissionsPermissionsTypedDict",
    "SetPermissionsRequestBody",
    "SetPermissionsRequestBodyTypedDict",
    "SetPermissionsResponse",
    "SetPermissionsResponseBody",
    "SetPermissionsResponseBodyTypedDict",
    "SetPermissionsResponseTypedDict",
    "SetRolesRequestBody",
    "SetRolesRequestBodyTypedDict",
    "SetRolesResponse",
    "SetRolesResponseBody",
    "SetRolesResponseBodyTypedDict",
    "SetRolesResponseTypedDict",
    "SetRolesRoles",
    "SetRolesRolesTypedDict",
    "Tag",
    "TagTypedDict",
    "Two",
    "Type",
    "UpdateIdentityIdentitiesRatelimits",
    "UpdateIdentityIdentitiesRatelimitsTypedDict",
    "UpdateIdentityRatelimits",
    "UpdateIdentityRatelimitsTypedDict",
    "UpdateIdentityRequestBody",
    "UpdateIdentityRequestBodyTypedDict",
    "UpdateIdentityResponse",
    "UpdateIdentityResponseBody",
    "UpdateIdentityResponseBodyTypedDict",
    "UpdateIdentityResponseTypedDict",
    "UpdateKeyInterval",
    "UpdateKeyPermissions",
    "UpdateKeyPermissionsTypedDict",
    "UpdateKeyRatelimit",
    "UpdateKeyRatelimitTypedDict",
    "UpdateKeyRefill",
    "UpdateKeyRefillTypedDict",
    "UpdateKeyRequestBody",
    "UpdateKeyRequestBodyTypedDict",
    "UpdateKeyResponse",
    "UpdateKeyResponseBody",
    "UpdateKeyResponseBodyTypedDict",
    "UpdateKeyResponseTypedDict",
    "UpdateKeyType",
    "UpdateRemainingRequestBody",
    "UpdateRemainingRequestBodyTypedDict",
    "UpdateRemainingResponse",
    "UpdateRemainingResponseBody",
    "UpdateRemainingResponseBodyTypedDict",
    "UpdateRemainingResponseTypedDict",
    "V1KeysVerifyKeyRequest",
    "V1KeysVerifyKeyRequestRatelimit",
    "V1KeysVerifyKeyRequestRatelimitTypedDict",
    "V1KeysVerifyKeyRequestTypedDict",
    "V1KeysVerifyKeyResponse",
    "V1KeysVerifyKeyResponseIdentity",
    "V1KeysVerifyKeyResponseIdentityTypedDict",
    "V1KeysVerifyKeyResponseRatelimit",
    "V1KeysVerifyKeyResponseRatelimitTypedDict",
    "V1KeysVerifyKeyResponseTypedDict",
    "V1LivenessResponse",
    "V1LivenessResponseBody",
    "V1LivenessResponseBodyTypedDict",
    "V1LivenessResponseTypedDict",
    "V1MigrationsCreateKeysInterval",
    "V1MigrationsCreateKeysRatelimit",
    "V1MigrationsCreateKeysRatelimitTypedDict",
    "V1MigrationsCreateKeysRefill",
    "V1MigrationsCreateKeysRefillTypedDict",
    "V1MigrationsCreateKeysResponse",
    "V1MigrationsCreateKeysResponseBody",
    "V1MigrationsCreateKeysResponseBodyTypedDict",
    "V1MigrationsCreateKeysResponseTypedDict",
    "V1MigrationsCreateKeysType",
    "V1MigrationsEnqueueKeysHash",
    "V1MigrationsEnqueueKeysHashTypedDict",
    "V1MigrationsEnqueueKeysInterval",
    "V1MigrationsEnqueueKeysKeys",
    "V1MigrationsEnqueueKeysKeysTypedDict",
    "V1MigrationsEnqueueKeysRatelimit",
    "V1MigrationsEnqueueKeysRatelimitTypedDict",
    "V1MigrationsEnqueueKeysRefill",
    "V1MigrationsEnqueueKeysRefillTypedDict",
    "V1MigrationsEnqueueKeysRequestBody",
    "V1MigrationsEnqueueKeysRequestBodyTypedDict",
    "V1MigrationsEnqueueKeysResponse",
    "V1MigrationsEnqueueKeysResponseBody",
    "V1MigrationsEnqueueKeysResponseBodyTypedDict",
    "V1MigrationsEnqueueKeysResponseTypedDict",
    "V1MigrationsEnqueueKeysType",
    "V1MigrationsEnqueueKeysVariant",
    "Variant",
    "Verifications",
    "VerificationsTypedDict",
    "VerifyKeyResponse",
    "VerifyKeyResponseTypedDict",
    "WhoamiIdentity",
    "WhoamiIdentityTypedDict",
    "WhoamiRequestBody",
    "WhoamiRequestBodyTypedDict",
    "WhoamiResponse",
    "WhoamiResponseBody",
    "WhoamiResponseBodyTypedDict",
    "WhoamiResponseTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict
from unkey_py.types import BaseModel
from unkey_py.utils import FieldMetadata, QueryParamMetadata


class GetRoleRequestTypedDict(TypedDict):
    role_id: str


class GetRoleRequest(BaseModel):
    role_id: Annotated[
        str,
        pydantic.Field(alias="roleId"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ]


class GetRoleResponseBodyTypedDict(TypedDict):
    r"""The Role"""

    id: str
    r"""The id of the role"""
    name: str
    r"""The name of the role."""
    description: NotRequired[str]
    r"""The description of what this role does. This is just for your team, your users will not see this."""


class GetRoleResponseBody(BaseModel):
    r"""The Role"""

    id: str
    r"""The id of the role"""

    name: str
    r"""The name of the role."""

    description: Optional[str] = None
    r"""The description of what this role does. This is just for your team, your users will not see this."""


class GetRoleResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    object: NotRequired[GetRoleResponseBodyTypedDict]
    r"""The Role"""


class GetRoleResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    object: Optional[GetRoleResponseBody] = None
    r"""The Role"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict
from unkey_py.types import BaseModel


class RemovePermissionsPermissionsTypedDict(TypedDict):
    id: NotRequired[str]
    r"""The id of the permission. Provide either `id` or `name`. If both are provided `id` is used."""
    name: NotRequired[str]
    r"""Identify the permission via its name. Provide either `id` or `name`. If both are provided `id` is used."""


class RemovePermissionsPermissions(BaseModel):
    id: Optional[str] = None
    r"""The id of the permission. Provide either `id` or `name`. If both are provided `id` is used."""

    name: Optional[str] = None
    r"""Identify the permission via its name. Provide either `id` or `name`. If both are provided `id` is used."""


class RemovePermissionsRequestBodyTypedDict(TypedDict):
    key_id: str
    r"""The id of the key."""
    permissions: List[RemovePermissionsPermissionsTypedDict]
    r"""The permissions you want to remove from this key."""


class RemovePermissionsRequestBody(BaseModel):
    key_id: Annotated[str, pydantic.Field(alias="keyId")]
    r"""The id of the key."""

    permissions: List[RemovePermissionsPermissions]
    r"""The permissions you want to remove from this key."""


class RemovePermissionsResponseBodyTypedDict(TypedDict):
    r"""Success"""


class RemovePermissionsResponseBody(BaseModel):
    r"""Success"""


class RemovePermissionsResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    object: NotRequired[RemovePermissionsResponseBodyTypedDict]
    r"""Success"""


class RemovePermissionsResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    object: Optional[RemovePermissionsResponseBody] = None
    r"""Success"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict
from unkey_py.types import BaseModel


class DeleteAPIRequestBodyTypedDict(TypedDict):
    api_id: str
    r"""The id of the api to delete"""


class DeleteAPIRequestBody(BaseModel):
    api_id: Annotated[str, pydantic.Field(alias="apiId")]
    r"""The id of the api to delete"""


class DeleteAPIResponseBodyTypedDict(TypedDict):
    r"""The api was successfully deleted, it may take up to 30s for this to take effect in all regions"""


class DeleteAPIResponseBody(BaseModel):
    r"""The api was successfully deleted, it may take up to 30s for this to take effect in all regions"""


class DeleteAPIResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    object: NotRequired[DeleteAPIResponseBodyTypedDict]
    r"""The api was successfully deleted, it may take up to 30s for this to take effect in all regions"""


class DeleteAPIResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    object: Optional[DeleteAPIResponseBody] = None
    r"""The api was successfully deleted, it may take up to 30s for this to take effect in all regions"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from typing import Any, Mapping, Optional
from unkey_py import models, utils
from unkey_py._hooks import HookContext
from unkey_py.types import OptionalNullable, UNSET
from unkey_py.utils import get_security_from_env


class Liveness(BaseSDK):
    def check(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.V1LivenessResponse:
        r"""
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request(
            method="GET",
            path="/v1/liveness",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(50, 1000, 1.5, 30000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="v1.liveness",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "409",
                "412",
                "429",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.V1LivenessResponse(
                object=utils.unmarshal_json(
                    http_res.text, Optional[models.V1LivenessResponseBody]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ErrBadRequestData
            )
            raise models.ErrBadRequest(data=response_data)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ErrUnauthorizedData
            )
            raise models.ErrUnauthorized(data=response_data)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(http_res.text, models.ErrForbiddenData)
            raise models.ErrForbidden(data=response_data)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json(http_res.text, models.ErrNotFoundData)
            raise models.ErrNotFound(data=response_data)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = utils.unmarshal_json(http_res.text, models.ErrConflictData)
            raise models.ErrConflict(data=response_data)
        if utils.match_response(http_res, "412", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ErrPreconditionFailedData
            )
            raise models.ErrPreconditionFailed(data=response_data)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ErrTooManyRequestsData
            )
            raise models.ErrTooManyRequests(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ErrInternalServerErrorData
            )
            raise models.ErrInternalServerError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def check_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.V1LivenessResponse:
        r"""
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request_async(
            method="GET",
            path="/v1/liveness",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(50, 1000, 1.5, 30000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="v1.liveness",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "409",
                "412",
                "429",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.V1LivenessResponse(
                object=utils.unmarshal_json(
                    http_res.text, Optional[models.V1LivenessResponseBody]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ErrBadRequestData
            )
            raise models.ErrBadRequest(data=response_data)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ErrUnauthorizedData
            )
            raise models.ErrUnauthorized(data=response_data)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = utils.unmarshal_json(http_res.text, models.ErrForbiddenData)
            raise models.ErrForbidden(data=response_data)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json(http_res.text, models.ErrNotFoundData)
            raise models.ErrNotFound(data=response_data)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = utils.unmarshal_json(http_res.text, models.ErrConflictData)
            raise models.ErrConflict(data=response_data)
        if utils.match_response(http_res, "412", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ErrPreconditionFailedData
            )
            raise models.ErrPreconditionFailed(data=response_data)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ErrTooManyRequestsData
            )
            raise models.ErrTooManyRequests(data=response_data)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.ErrInternalServerErrorData
            )
            raise models.ErrInternalServerError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict
from unkey_py.types import BaseModel
from unkey_py.utils import FieldMetadata, QueryParamMetadata


class GetAPIRequestTypedDict(TypedDict):
    api_id: str


class GetAPIRequest(BaseModel):
    api_id: Annotated[
        str,
        pydantic.Field(alias="apiId"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ]


class GetAPIResponseBodyTypedDict(TypedDict):
    r"""The configuration for an api"""

    id: str
    r"""The id of the key"""
    workspace_id: str
    r"""The id of the workspace that owns the api"""
    name: NotRequired[str]
    r"""The name of the api. This is internal and your users will not see this."""


class GetAPIResponseBody(BaseModel):
    r"""The configuration for an api"""

    id: str
    r"""The id of the key"""

    workspace_id: Annotated[str, pydantic.Field(alias="workspaceId")]
    r"""The id of the workspace that owns the api"""

    name: Optional[str] = None
    r"""The name of the api. This is internal and your users will not see this."""


class GetAPIResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    object: NotRequired[GetAPIResponseBodyTypedDict]
    r"""The configuration for an api"""


class GetAPIResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    object: Optional[GetAPIResponseBody] = None
    r"""The configuration for an api"""
